##  Resources
In the resources section within the manifest file, you can define the resources associated with your microservice. For more information, see [Storing Resources on Fact Sheets](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD "Explore how to collaborate and manage data in SAP LeanIX fact sheets. Learn how to add and handle data across various tabs of the fact sheet, including Subscriptions, Comments, To-dos, Resources, Transformations, and Surveys.").
Attribute | Required | Description
---|---|---
name | Yes | The name of the resource.
type | Yes | The resource type. You can find a list of supported resource types in the API documentation.
url | No | The URL of the resource.
description | No | The description of the resource.


